@@ -45,6 +45,11 @@ impl CacheEntry {
         Self(path.into())
     }
 
+    /// Return the cache entry's parent directory.
+    pub fn shard(&self) -> CacheShard {
+        CacheShard(self.dir().to_path_buf())
+    }
+
     /// Convert the [`CacheEntry`] into a [`PathBuf`].
     #[inline]
     pub fn into_path_buf(self) -> PathBuf {
@@ -447,12 +452,31 @@ impl Cache {
                 Err(err) => return Err(err),
             }
 
-            // Remove any unzipped wheels (i.e., symlinks) from the built wheels cache.
             for entry in walkdir::WalkDir::new(self.bucket(CacheBucket::SourceDistributions)) {
                 let entry = entry?;
-                if entry.file_type().is_symlink() {
-                    debug!("Removing unzipped wheel entry: {}", entry.path().display());
-                    summary += rm_rf(entry.path())?;
+
+                // If the directory contains a `metadata.msgpack`, then it's a built wheel revision.
+                if !entry.file_type().is_dir() {
+                    continue;
+                }
+
+                if !entry.path().join("metadata.msgpack").exists() {
+                    continue;
+                }
+
+                // Remove any symlinks and directories in the revision. The symlinks represent
+                // unzipped wheels, and the directories represent the source distribution archives.
+                for entry in fs_err::read_dir(entry.path())? {
+                    let entry = entry?;
+                    let path = entry.path();
+
+                    if path.is_dir() {
+                        debug!("Removing unzipped built wheel entry: {}", path.display());
+                        summary += rm_rf(path)?;
+                    } else if path.is_symlink() {
+                        debug!("Removing unzipped built wheel entry: {}", path.display());
+                        summary += rm_rf(path)?;
+                    }
                 }
             }
         }
@@ -740,15 +764,16 @@ pub enum CacheBucket {
 impl CacheBucket {
     fn to_str(self) -> &'static str {
         match self {
-            // Note, next time we change the version we should change the name of this bucket to `source-dists-v0`
-            Self::SourceDistributions => "built-wheels-v3",
+            Self::SourceDistributions => "sdists-v4",
             Self::FlatIndex => "flat-index-v0",
             Self::Git => "git-v0",
             Self::Interpreter => "interpreter-v2",
             // Note that when bumping this, you'll also need to bump it
             // in crates/uv/tests/cache_clean.rs.
-            Self::Simple => "simple-v12",
-            Self::Wheels => "wheels-v1",
+            Self::Simple => "simple-v13",
+            // Note that when bumping this, you'll also need to bump it
+            // in crates/uv/tests/cache_prune.rs.
+            Self::Wheels => "wheels-v2",
             Self::Archive => "archive-v0",
             Self::Builds => "builds-v0",
             Self::Environments => "environments-v1",
