@@ -1,3 +1,4 @@
+use cache_key::CacheKeyHasher;
 use std::{
     collections::{btree_map::Entry, BTreeMap},
     str::FromStr,
@@ -108,6 +109,16 @@ impl FromIterator<ConfigSettingEntry> for ConfigSettings {
 }
 
 impl ConfigSettings {
+    /// Returns the number of settings in the configuration.
+    pub fn len(&self) -> usize {
+        self.0.len()
+    }
+
+    /// Returns `true` if the configuration contains no settings.
+    pub fn is_empty(&self) -> bool {
+        self.0.is_empty()
+    }
+
     /// Convert the settings to a string that can be passed directly to a PEP 517 build backend.
     pub fn escape_for_python(&self) -> String {
         serde_json::to_string(self).expect("Failed to serialize config settings")
@@ -150,6 +161,18 @@ impl ConfigSettings {
     }
 }
 
+impl cache_key::CacheKey for ConfigSettings {
+    fn cache_key(&self, state: &mut CacheKeyHasher) {
+        for (key, value) in &self.0 {
+            key.cache_key(state);
+            match value {
+                ConfigSettingValue::String(value) => value.cache_key(state),
+                ConfigSettingValue::List(values) => values.cache_key(state),
+            }
+        }
+    }
+}
+
 impl serde::Serialize for ConfigSettings {
     fn serialize<S: serde::Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
         use serde::ser::SerializeMap;
