@@ -3,6 +3,8 @@ pub use build_options::*;
 pub use concurrency::*;
 pub use config_settings::*;
 pub use constraints::*;
+pub use dev::*;
+pub use editable::*;
 pub use export_format::*;
 pub use extras::*;
 pub use hash::*;
@@ -20,6 +22,8 @@ mod build_options;
 mod concurrency;
 mod config_settings;
 mod constraints;
+mod dev;
+mod editable;
 mod export_format;
 mod extras;
 mod hash;
