@@ -5,6 +5,7 @@ use distribution_types::{
     VersionOrUrlRef,
 };
 use pep440_rs::Version;
+use pep508_rs::MarkerTree;
 use pypi_types::HashDigest;
 use uv_distribution::Metadata;
 use uv_normalize::{ExtraName, GroupName, PackageName};
@@ -30,6 +31,7 @@ pub(crate) struct AnnotatedDist {
     pub(crate) dev: Option<GroupName>,
     pub(crate) hashes: Vec<HashDigest>,
     pub(crate) metadata: Option<Metadata>,
+    pub(crate) marker: MarkerTree,
 }
 
 impl AnnotatedDist {
