@@ -1,10 +1,16 @@
+use std::env;
+
 use anyhow::{Context, Result};
+use itertools::Itertools;
 use owo_colors::OwoColorize;
 use std::path::PathBuf;
 
 use uv_cache::Cache;
 use uv_client::Connectivity;
-use uv_configuration::{Concurrency, ExportFormat, ExtrasSpecification, InstallOptions};
+use uv_configuration::{
+    Concurrency, DevMode, DevSpecification, EditableMode, ExportFormat, ExtrasSpecification,
+    InstallOptions,
+};
 use uv_fs::CWD;
 use uv_normalize::{PackageName, DEV_DEPENDENCIES};
 use uv_python::{PythonDownloads, PythonPreference, PythonRequest};
@@ -27,7 +33,8 @@ pub(crate) async fn export(
     install_options: InstallOptions,
     output_file: Option<PathBuf>,
     extras: ExtrasSpecification,
-    dev: bool,
+    dev: DevMode,
+    editable: EditableMode,
     locked: bool,
     frozen: bool,
     python: Option<String>,
@@ -108,10 +115,10 @@ pub(crate) async fn export(
     };
 
     // Include development dependencies, if requested.
-    let dev = if dev {
-        vec![DEV_DEPENDENCIES.clone()]
-    } else {
-        vec![]
+    let dev = match dev {
+        DevMode::Include => DevSpecification::Include(std::slice::from_ref(&DEV_DEPENDENCIES)),
+        DevMode::Exclude => DevSpecification::Exclude,
+        DevMode::Only => DevSpecification::Only(std::slice::from_ref(&DEV_DEPENDENCIES)),
     };
 
     // Write the resolved dependencies to the output channel.
@@ -124,15 +131,17 @@ pub(crate) async fn export(
                 &lock,
                 project.project_name(),
                 &extras,
-                &dev,
+                dev,
+                editable,
                 hashes,
                 &install_options,
             )?;
             writeln!(
                 writer,
                 "{}",
-                "# This file was autogenerated via `uv export`.".green()
+                "# This file was autogenerated by uv via the following command:".green()
             )?;
+            writeln!(writer, "{}", format!("#    {}", cmd()).green())?;
             write!(writer, "{export}")?;
         }
     }
@@ -141,3 +150,54 @@ pub(crate) async fn export(
 
     Ok(ExitStatus::Success)
 }
+
+/// Format the uv command used to generate the output file.
+fn cmd() -> String {
+    let args = env::args_os()
+        .skip(1)
+        .map(|arg| arg.to_string_lossy().to_string())
+        .scan(None, move |skip_next, arg| {
+            if matches!(skip_next, Some(true)) {
+                // Reset state; skip this iteration.
+                *skip_next = None;
+                return Some(None);
+            }
+
+            // Always skip the `--upgrade` flag.
+            if arg == "--upgrade" || arg == "-U" {
+                *skip_next = None;
+                return Some(None);
+            }
+
+            // Always skip the `--upgrade-package` and mark the next item to be skipped
+            if arg == "--upgrade-package" || arg == "-P" {
+                *skip_next = Some(true);
+                return Some(None);
+            }
+
+            // Skip only this argument if option and value are together
+            if arg.starts_with("--upgrade-package=") || arg.starts_with("-P") {
+                // Reset state; skip this iteration.
+                *skip_next = None;
+                return Some(None);
+            }
+
+            // Always skip the `--quiet` flag.
+            if arg == "--quiet" || arg == "-q" {
+                *skip_next = None;
+                return Some(None);
+            }
+
+            // Always skip the `--verbose` flag.
+            if arg == "--verbose" || arg == "-v" {
+                *skip_next = None;
+                return Some(None);
+            }
+
+            // Return the argument.
+            Some(Some(arg))
+        })
+        .flatten()
+        .join(" ");
+    format!("uv {args}")
+}
