@@ -14,7 +14,9 @@ use tracing::{debug, warn};
 use uv_cache::Cache;
 use uv_cli::ExternalCommand;
 use uv_client::{BaseClientBuilder, Connectivity};
-use uv_configuration::{Concurrency, ExtrasSpecification, InstallOptions};
+use uv_configuration::{
+    Concurrency, DevMode, EditableMode, ExtrasSpecification, InstallOptions, SourceStrategy,
+};
 use uv_distribution::LoweredRequirement;
 use uv_fs::{PythonExt, Simplified, CWD};
 use uv_installer::{SatisfiesResult, SitePackages};
@@ -57,7 +59,8 @@ pub(crate) async fn run(
     no_project: bool,
     no_config: bool,
     extras: ExtrasSpecification,
-    dev: bool,
+    dev: DevMode,
+    editable: EditableMode,
     python: Option<String>,
     settings: ResolverInstallerSettings,
     python_preference: PythonPreference,
@@ -175,13 +178,16 @@ pub(crate) async fn run(
         if let Some(dependencies) = script.metadata.dependencies {
             // // Collect any `tool.uv.sources` from the script.
             let empty = BTreeMap::default();
-            let script_sources = script
-                .metadata
-                .tool
-                .as_ref()
-                .and_then(|tool| tool.uv.as_ref())
-                .and_then(|uv| uv.sources.as_ref())
-                .unwrap_or(&empty);
+            let script_sources = match settings.sources {
+                SourceStrategy::Enabled => script
+                    .metadata
+                    .tool
+                    .as_ref()
+                    .and_then(|tool| tool.uv.as_ref())
+                    .and_then(|uv| uv.sources.as_ref())
+                    .unwrap_or(&empty),
+                SourceStrategy::Disabled => &empty,
+            };
             let script_path = std::path::absolute(script.path)?;
             let script_dir = script_path.parent().expect("script path has no parent");
 
@@ -244,6 +250,7 @@ pub(crate) async fn run(
                 false,
                 false,
                 false,
+                false,
             )?;
 
             Some(environment.into_interpreter())
@@ -264,9 +271,12 @@ pub(crate) async fn run(
         if !extras.is_empty() {
             warn_user!("Extras are not supported for Python scripts with inline metadata");
         }
-        if !dev {
+        if matches!(dev, DevMode::Exclude) {
             warn_user!("`--no-dev` is not supported for Python scripts with inline metadata");
         }
+        if matches!(dev, DevMode::Only) {
+            warn_user!("`--only-dev` is not supported for Python scripts with inline metadata");
+        }
         if package.is_some() {
             warn_user!(
                 "`--package` is a no-op for Python scripts with inline metadata, which always run in isolation"
@@ -338,9 +348,12 @@ pub(crate) async fn run(
             if !extras.is_empty() {
                 warn_user!("Extras have no effect when used alongside `--no-project`");
             }
-            if !dev {
+            if matches!(dev, DevMode::Exclude) {
                 warn_user!("`--no-dev` has no effect when used alongside `--no-project`");
             }
+            if matches!(dev, DevMode::Only) {
+                warn_user!("`--only-dev` has no effect when used alongside `--no-project`");
+            }
             if locked {
                 warn_user!("`--locked` has no effect when used alongside `--no-project`");
             }
@@ -355,9 +368,12 @@ pub(crate) async fn run(
             if !extras.is_empty() {
                 warn_user!("Extras have no effect when used outside of a project");
             }
-            if !dev {
+            if matches!(dev, DevMode::Exclude) {
                 warn_user!("`--no-dev` has no effect when used outside of a project");
             }
+            if matches!(dev, DevMode::Only) {
+                warn_user!("`--only-dev` has no effect when used outside of a project");
+            }
             if locked {
                 warn_user!("`--locked` has no effect when used outside of a project");
             }
@@ -429,6 +445,7 @@ pub(crate) async fn run(
                     false,
                     false,
                     false,
+                    false,
                 )?
             } else {
                 // If we're not isolating the environment, reuse the base environment for the
@@ -487,6 +504,7 @@ pub(crate) async fn run(
                     result.lock(),
                     &extras,
                     dev,
+                    editable,
                     install_options,
                     Modifications::Sufficient,
                     settings.as_ref().into(),
@@ -551,6 +569,7 @@ pub(crate) async fn run(
                     false,
                     false,
                     false,
+                    false,
                 )?;
                 venv.into_interpreter()
             } else {
@@ -599,6 +618,7 @@ pub(crate) async fn run(
                     false,
                     false,
                     false,
+                    false,
                 )?
             }
             Some(spec) => {
@@ -643,10 +663,7 @@ pub(crate) async fn run(
                         eprint!("{err:?}");
                         return Ok(ExitStatus::Failure);
                     }
-
-                    Err(err) => {
-                        return Err(err.into());
-                    }
+                    Err(err) => return Err(err.into()),
                 };
 
                 environment.into()
