@@ -56,7 +56,7 @@ fn run_with_python_version() -> Result<()> {
 
     ----- stderr -----
     Using Python 3.12.[X] interpreter at: [PYTHON-3.12]
-    Creating virtualenv at: .venv
+    Creating virtual environment at: .venv
     Resolved 5 packages in [TIME]
     Prepared 4 packages in [TIME]
     Installed 4 packages in [TIME]
@@ -106,9 +106,9 @@ fn run_with_python_version() -> Result<()> {
     ----- stderr -----
     Using Python 3.11.[X] interpreter at: [PYTHON-3.11]
     Removed virtual environment at: .venv
-    Creating virtualenv at: .venv
+    Creating virtual environment at: .venv
     Resolved 5 packages in [TIME]
-    Prepared 3 packages in [TIME]
+    Prepared 1 package in [TIME]
     Installed 4 packages in [TIME]
      + anyio==3.6.0
      + foo==1.0.0 (from file://[TEMP_DIR]/)
@@ -810,7 +810,7 @@ fn run_with_editable() -> Result<()> {
     "###);
 
     // If invalid, we should reference `--with-editable`.
-    uv_snapshot!(context.filters(), context.run().arg("--with").arg("./foo").arg("main.py"), @r###"
+    uv_snapshot!(context.filters(), context.run().arg("--with-editable").arg("./foo").arg("main.py"), @r###"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -1186,7 +1186,6 @@ fn run_requirements_txt() -> Result<()> {
     Resolved 6 packages in [TIME]
     Audited 4 packages in [TIME]
     Resolved 2 packages in [TIME]
-    Prepared 1 package in [TIME]
     Installed 2 packages in [TIME]
      + iniconfig==2.0.0
      + sniffio==1.3.1
@@ -1365,7 +1364,7 @@ fn run_from_directory() -> Result<()> {
     ----- stderr -----
     warning: `VIRTUAL_ENV=[VENV]/` does not match the project environment path `.venv` and will be ignored
     Using Python 3.12.[X] interpreter at: [PYTHON-3.12]
-    Creating virtualenv at: .venv
+    Creating virtual environment at: .venv
     Resolved 1 package in [TIME]
     Prepared 1 package in [TIME]
     Installed 1 package in [TIME]
@@ -1464,7 +1463,7 @@ fn run_isolated_python_version() -> Result<()> {
 
     ----- stderr -----
     Using Python 3.8.[X] interpreter at: [PYTHON-3.8]
-    Creating virtualenv at: .venv
+    Creating virtual environment at: .venv
     Resolved 6 packages in [TIME]
     Prepared 6 packages in [TIME]
     Installed 6 packages in [TIME]
@@ -1484,7 +1483,6 @@ fn run_isolated_python_version() -> Result<()> {
 
     ----- stderr -----
     Resolved 6 packages in [TIME]
-    Prepared 5 packages in [TIME]
     Installed 6 packages in [TIME]
      + anyio==4.3.0
      + exceptiongroup==1.2.0
@@ -1508,7 +1506,6 @@ fn run_isolated_python_version() -> Result<()> {
 
     ----- stderr -----
     Resolved 6 packages in [TIME]
-    Prepared 3 packages in [TIME]
     Installed 4 packages in [TIME]
      + anyio==4.3.0
      + foo==1.0.0 (from file://[TEMP_DIR]/)
@@ -1910,3 +1907,85 @@ fn run_exit_code() -> Result<()> {
 
     Ok(())
 }
+
+#[test]
+fn run_invalid_project_table() -> Result<()> {
+    let context = TestContext::new_with_versions(&["3.12", "3.11", "3.8"]);
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! { r#"
+        [project.urls]
+        repository = 'https://github.com/octocat/octocat-python'
+
+        [build-system]
+        requires = ["setuptools>=42"]
+        build-backend = "setuptools.build_meta"
+        "#
+    })?;
+
+    let test_script = context.temp_dir.child("main.py");
+    test_script.write_str(indoc! { r#"
+        print("Hello, world!")
+       "#
+    })?;
+
+    uv_snapshot!(context.filters(), context.run().arg("main.py"), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Failed to parse: `pyproject.toml`
+      Caused by: `pyproject.toml` is using the `[project]` table, but the required `project.name` field is not set
+      Caused by: TOML parse error at line 1, column 2
+      |
+    1 | [project.urls]
+      |  ^^^^^^^
+    missing field `name`
+
+    "###);
+
+    Ok(())
+}
+
+#[test]
+#[cfg(target_family = "unix")]
+fn run_script_without_build_system() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(indoc! { r#"
+        [project]
+        name = "foo"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+        dependencies = []
+
+        [project.scripts]
+        entry = "foo:custom_entry"
+        "#
+    })?;
+
+    let test_script = context.temp_dir.child("src/__init__.py");
+    test_script.write_str(indoc! { r#"
+        def custom_entry():
+            print!("Hello")
+       "#
+    })?;
+
+    // TODO(lucab): this should match `entry` and warn
+    // <https://github.com/astral-sh/uv/issues/7428>
+    uv_snapshot!(context.filters(), context.run().arg("entry"), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 1 package in [TIME]
+    Audited in [TIME]
+    error: Failed to spawn: `entry`
+      Caused by: No such file or directory (os error 2)
+    "###);
+
+    Ok(())
+}
