@@ -1747,7 +1747,7 @@ fn sync_custom_environment_path() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    error: Project virtual environment directory `[TEMP_DIR]/foo` cannot be used because it is not a virtual environment and is non-empty
+    error: Project virtual environment directory `[TEMP_DIR]/foo` cannot be used because because it is not a valid Python environment (no Python executable was found)
     "###);
 
     // But if it's just an incompatible virtual environment...
@@ -2640,7 +2640,7 @@ fn sync_invalid_environment() -> Result<()> {
     ----- stdout -----
 
     ----- stderr -----
-    error: Project virtual environment directory `[VENV]/` cannot be used because it is not a virtual environment and is non-empty
+    error: Project virtual environment directory `[VENV]/` cannot be used because because it is not a valid Python environment (no Python executable was found)
     "###);
 
     // But if it's just an incompatible virtual environment...
@@ -2677,10 +2677,11 @@ fn sync_invalid_environment() -> Result<()> {
 
     let bin = venv_bin_path(context.temp_dir.join(".venv"));
 
-    // If it's there's a broken symlink, we should warn
+    // If there's just a broken symlink, we should warn
     #[cfg(unix)]
     {
         fs_err::remove_file(bin.join("python"))?;
+        fs_err::os::unix::fs::symlink(context.temp_dir.join("does-not-exist"), bin.join("python"))?;
         uv_snapshot!(context.filters(), context.sync(), @r###"
         success: true
         exit_code: 0
@@ -2697,21 +2698,107 @@ fn sync_invalid_environment() -> Result<()> {
         "###);
     }
 
-    // And if the Python executable is missing entirely we should warn
+    // But if the Python executable is missing entirely we should also fail
     fs_err::remove_dir_all(&bin)?;
     uv_snapshot!(context.filters(), context.sync(), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    error: Project virtual environment directory `[VENV]/` cannot be used because because it is not a valid Python environment (no Python executable was found)
+    "###);
+
+    // But if it's not a virtual environment...
+    fs_err::remove_dir_all(context.temp_dir.join(".venv"))?;
+    uv_snapshot!(context.filters(), context.venv().arg("--python").arg("3.11"), @r###"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
-    warning: Ignoring existing virtual environment with missing Python interpreter: .venv/[BIN]/python
-    Using Python 3.12.[X] interpreter at: [PYTHON-3.12]
-    Removed virtual environment at: .venv
+    Using Python 3.11.[X] interpreter at: [PYTHON-3.11]
     Creating virtual environment at: .venv
-    Resolved 2 packages in [TIME]
-    Installed 1 package in [TIME]
-     + iniconfig==2.0.0
+    Activate with: source .venv/[BIN]/activate
+    "###);
+
+    // Which we detect by the presence of a `pyvenv.cfg` file
+    fs_err::remove_file(context.temp_dir.join(".venv").join("pyvenv.cfg"))?;
+
+    // Let's make sure some extraneous content isn't removed
+    fs_err::write(context.temp_dir.join(".venv").join("file"), b"")?;
+
+    // We should never delete it
+    uv_snapshot!(context.filters(), context.sync(), @r###"
+    success: false
+    exit_code: 2
+    ----- stdout -----
+
+    ----- stderr -----
+    Using Python 3.12.[X] interpreter at: [PYTHON-3.12]
+    error: Project virtual environment directory `[VENV]/` cannot be used because it is not a compatible environment but cannot be recreated because it is not a virtual environment
+    "###);
+
+    context
+        .temp_dir
+        .child(".venv")
+        .assert(predicate::path::is_dir());
+
+    context
+        .temp_dir
+        .child(".venv")
+        .child("file")
+        .assert(predicate::path::is_file());
+
+    Ok(())
+}
+
+/// Avoid validating workspace members when `--no-sources` is provided. Rather than reporting that
+/// `./anyio` is missing, install `anyio` from the registry.
+#[test]
+fn sync_no_sources_missing_member() -> Result<()> {
+    let context = TestContext::new("3.12");
+
+    let pyproject_toml = context.temp_dir.child("pyproject.toml");
+    pyproject_toml.write_str(
+        r#"
+        [project]
+        name = "root"
+        version = "0.1.0"
+        requires-python = ">=3.12"
+        dependencies = ["anyio"]
+
+        [build-system]
+        requires = ["setuptools>=42"]
+        build-backend = "setuptools.build_meta"
+
+        [tool.uv.sources]
+        anyio = { workspace = true }
+
+        [tool.uv.workspace]
+        members = ["anyio"]
+        "#,
+    )?;
+
+    let src = context.temp_dir.child("src").child("albatross");
+    src.create_dir_all()?;
+
+    let init = src.child("__init__.py");
+    init.touch()?;
+
+    uv_snapshot!(context.filters(), context.sync().arg("--no-sources"), @r###"
+    success: true
+    exit_code: 0
+    ----- stdout -----
+
+    ----- stderr -----
+    Resolved 4 packages in [TIME]
+    Prepared 4 packages in [TIME]
+    Installed 4 packages in [TIME]
+     + anyio==4.3.0
+     + idna==3.6
+     + root==0.1.0 (from file://[TEMP_DIR]/)
+     + sniffio==1.3.1
     "###);
 
     Ok(())
